<?php
/**
 * Team Section options
 *
 * @package Theme Palace
 * @subpackage Corporate Education Pro
 * @since Corporate Education Pro 1.0
 */

$wp_customize->add_section( 'corporate_education_pro_team', array(
	'title'             => esc_html__( 'Team','corporate-education-pro' ),
	'description'       => esc_html__( 'Team Section Options.', 'corporate-education-pro' ),
	'panel'             => 'corporate_education_pro_sections_panel',
) );

// team Section enable setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[team_enable]', array(
	'sanitize_callback'	=> 'corporate_education_pro_sanitize_checkbox',
	'default'          	=> $options['team_enable'],
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[team_enable]', array(
	'label'            	=> esc_html__( 'Enable Team Section', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_team',
	'type'             	=> 'checkbox',
) );

// team Section content type setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[team_intro_content_type]', array(
	'default'          	=> $options['team_intro_content_type'],
	'sanitize_callback'	=> 'corporate_education_pro_sanitize_select',
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[team_intro_content_type]', array(
	'label'            	=> esc_html__( 'Team Intro Content Type', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_team',
	'type'             	=> 'select',
	'active_callback'	=> 'corporate_education_pro_is_team_enable',
	'choices'			=> corporate_education_pro_intro_content_type(),
) );

// // team Section content type post setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[team_intro_content_post]', array(
	'validate_callback' => 'corporate_education_pro_validate_post_id',
	'sanitize_callback' => 'corporate_education_pro_sanitize_single_post_id',
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[team_intro_content_post]', array(
	'active_callback'	=> 'corporate_education_pro_team_intro_content_post',
	'label'             => esc_html__( 'Input Post Id', 'corporate-education-pro' ),
	'description'       => esc_html__( 'Please Input Valid Post Id', 'corporate-education-pro' ),
	'section'           => 'corporate_education_pro_team',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'style'	=> 'width:100px',
		),
) );

// Show page drop-down setting and control
$wp_customize->add_setting( 'corporate_education_pro_theme_options[team_intro_content_page]', array(
	'sanitize_callback' => 'corporate_education_pro_sanitize_page'
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[team_intro_content_page]', array(
	'label'           	=> esc_html__( 'Select Page', 'corporate-education-pro' ),
	'section'        	=> 'corporate_education_pro_team',
	'active_callback' 	=> 'corporate_education_pro_team_intro_content_page',
	'type'				=> 'dropdown-pages'
) );

// team Section enable setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[team_intro_title]', array(
	'sanitize_callback'	=> 'sanitize_text_field',
	'default'          	=> $options['team_intro_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[team_intro_title]', array(
	'label'            	=> esc_html__( 'Intro Title', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_team',
	'type'             	=> 'text',
	'active_callback'	=> 'corporate_education_pro_team_intro_content_custom',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'corporate_education_pro_theme_options[team_intro_title]', array(
		'selector'            => '#team-members .entry-header h2.entry-title',
		'settings'            => 'corporate_education_pro_theme_options[team_intro_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'corporate_education_pro_team_intro_title',
    ) );
}

// team Section enable setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[team_intro_sub_title]', array(
	'sanitize_callback'	=> 'sanitize_text_field',
	'default'          	=> $options['team_intro_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[team_intro_sub_title]', array(
	'label'            	=> esc_html__( 'Intro Sub Title', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_team',
	'type'             	=> 'text',
	'active_callback'	=> 'corporate_education_pro_is_team_enable',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'corporate_education_pro_theme_options[team_intro_sub_title]', array(
		'selector'            => '#team-members .entry-header p.entry-title-desc',
		'settings'            => 'corporate_education_pro_theme_options[team_intro_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'corporate_education_pro_team_intro_sub_title',
    ) );
}

// team Section enable setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[team_intro_description]', array(
	'sanitize_callback'	=> 'wp_kses_post',
	'default'          	=> $options['team_intro_description'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[team_intro_description]', array(
	'label'            	=> esc_html__( 'Intro Description', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_team',
	'type'             	=> 'textarea',
	'active_callback'	=> 'corporate_education_pro_team_intro_content_custom',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'corporate_education_pro_theme_options[team_intro_description]', array(
		'selector'            => '#team-members .entry-content p',
		'settings'            => 'corporate_education_pro_theme_options[team_intro_description]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'corporate_education_pro_team_intro_description',
    ) );
}

// team Section enable setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[team_intro_btn_label]', array(
	'sanitize_callback'	=> 'sanitize_text_field',
	'default'          	=> $options['team_intro_btn_label'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[team_intro_btn_label]', array(
	'label'            	=> esc_html__( 'Intro Button Label', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_team',
	'type'             	=> 'text',
	'active_callback'	=> 'corporate_education_pro_team_intro_content_custom',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'corporate_education_pro_theme_options[team_intro_btn_label]', array(
		'selector'            => '#team-members .view-more a',
		'settings'            => 'corporate_education_pro_theme_options[team_intro_btn_label]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'corporate_education_pro_team_intro_btn_label',
    ) );
}

// team Section enable setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[team_intro_btn_url]', array(
	'sanitize_callback'	=> 'esc_url_raw',
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[team_intro_btn_url]', array(
	'label'            	=> esc_html__( 'Intro Button Link', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_team',
	'type'             	=> 'url',
	'active_callback'	=> 'corporate_education_pro_team_intro_content_custom',
) );

// team post hr setting and control
$wp_customize->add_setting( 'corporate_education_pro_theme_options[team_hr]', array(
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( new Corporate_Education_Pro_Customize_Horizontal_Line( $wp_customize, 'corporate_education_pro_theme_options[team_hr]',
	array(
		'section'         => 'corporate_education_pro_team',
		'active_callback' => 'corporate_education_pro_is_team_enable',
		'type'			  => 'hr'
) ) );

// team Section content type setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[team_content_type]', array(
	'default'          	=> $options['team_content_type'],
	'sanitize_callback'	=> 'corporate_education_pro_sanitize_select',
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[team_content_type]', array(
	'label'            	=> esc_html__( 'Team Content Type', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_team',
	'type'             	=> 'select',
	'active_callback'	=> 'corporate_education_pro_is_team_enable',
	'choices'			=> corporate_education_pro_team_content_type(),
) );

// team Section category setting and control
$wp_customize->add_setting( 'corporate_education_pro_theme_options[team_content_category]', array(
	'sanitize_callback' => 'corporate_education_pro_sanitize_single_category'
) );

$wp_customize->add_control( new Corporate_Education_Pro_Dropdown_Single_Category_Control( $wp_customize, 'corporate_education_pro_theme_options[team_content_category]', array(
	'label'           => esc_html__( 'Select Category', 'corporate-education-pro' ),
	'description'     => esc_html__( 'Six latest posts from selected category will be shown.', 'corporate-education-pro' ),
	'section'         => 'corporate_education_pro_team',
	'type'			  => 'dropdown-category',
	'active_callback' => 'corporate_education_pro_team_content_category',
) ) );

// team Section content type post setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[team_content_post]', array(
	'sanitize_callback' => 'corporate_education_pro_sanitize_post_ids',
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[team_content_post]', array(
	'active_callback'	=> 'corporate_education_pro_team_content_post',
	'label'             => esc_html__( 'Input Post Ids', 'corporate-education-pro' ),
	'description'       => esc_html__( 'Simply hover post title on dashboard to see the Post ID. Max no. of posts allowed is 6. ie: 11, 24, 34', 'corporate-education-pro' ),
	'section'           => 'corporate_education_pro_team',
	'type'				=> 'text'
) );

// team Section content type team setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[team_content_team]', array(
	'sanitize_callback' => 'corporate_education_pro_sanitize_post_ids',
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[team_content_team]', array(
	'active_callback'	=> 'corporate_education_pro_team_content_team',
	'label'             => esc_html__( 'Input Team Ids', 'corporate-education-pro' ),
	'description'       => esc_html__( 'Simply hover post title on dashboard to see the Post ID. Max no. of teams allowed is 6. ie: 11, 24, 34', 'corporate-education-pro' ),
	'section'           => 'corporate_education_pro_team',
	'type'				=> 'text'
) );

// team Section content type team category setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[team_content_team_category]', array(
	'sanitize_callback' => 'absint',
) );

$wp_customize->add_control( new Corporate_Education_Pro_Dropdown_Single_Category_Control( $wp_customize, 'corporate_education_pro_theme_options[team_content_team_category]', array(
	'label'           => esc_html__( 'Select Team Category', 'corporate-education-pro' ),
	'description'     => esc_html__( 'Six latest teams from selected category will be shown.', 'corporate-education-pro' ),
	'section'         => 'corporate_education_pro_team',
	'taxonomy'        => 'tp-team-category',
	'type'			  => 'dropdown-category',
	'active_callback' => 'corporate_education_pro_team_content_team_category',
) ) );